@@ -4,8 +4,10 @@
 #' @name mlr_optimizers_cmaes
 #'
 #' @description
-#' `OptimizerCmaes` class that implements CMA-ES. Calls
-#' [adagio::pureCMAES()] from package \CRANpkg{adagio}.
+#' `OptimizerCmaes` class that implements CMA-ES. Calls [adagio::pureCMAES()]
+#' from package \CRANpkg{adagio}. The algorithm is typically applied to search
+#' space dimensions between three and fifty. Lower search space dimensions might
+#' crash.
 #'
 #' @templateVar id cmaes
 #' @template section_dictionary_optimizers
@@ -27,37 +29,36 @@
 #' @export
 #' @examples
 #' if(requireNamespace("adagio")) {
-#' library(paradox)
-#'
-#' domain = ParamSet$new(list(ParamDbl$new("x", lower = -1, upper = 1)))
-#'
-#' search_space = ParamSet$new(list(ParamDbl$new("x", lower = -1, upper = 1)))
-#'
-#' codomain = ParamSet$new(list(ParamDbl$new("y", tags = "minimize")))
-#'
+#' search_space = domain = ps(
+#'   x1 = p_dbl(-10, 10),
+#'   x2 = p_dbl(-5, 5)
+#' )
+#' 
+#' codomain = ps(y = p_dbl(tags = "maximize"))
+#' 
 #' objective_function = function(xs) {
-#'   list(y = as.numeric(xs)^2)
+#'   c(y = - (xs[[1]] - 2)^2 - (xs[[2]] + 3)^2 + 10)
 #' }
-#'
-#' objective = ObjectiveRFun$new(fun = objective_function,
-#'                               domain = domain,
-#'                               codomain = codomain)
-#' terminator = trm("evals", n_evals = 10)
+#' 
+#' objective = ObjectiveRFun$new(
+#'   fun = objective_function,
+#'   domain = domain,
+#'   codomain = codomain)
+#' 
 #' instance = OptimInstanceSingleCrit$new(
-#'  objective = objective,
-#'  search_space = search_space,
-#'  terminator = terminator)
-#'
-#'
+#'   objective = objective,
+#'   search_space = search_space,
+#'   terminator = trm("evals", n_evals = 10))
+#' 
 #' optimizer = opt("cmaes")
-#'
-#' # Modifies the instance by reference
+#' 
+#' # modifies the instance by reference
 #' optimizer$optimize(instance)
-#'
-#' # Returns best scoring evaluation
+#' 
+#' # returns best scoring evaluation
 #' instance$result
-#'
-#' # Allows access of data.table of full path of all evaluations
+#' 
+#' # allows access of data.table of full path of all evaluations
 #' as.data.table(instance$archive$data)
 #' }
 OptimizerCmaes = R6Class("OptimizerCmaes",
@@ -67,13 +68,13 @@ OptimizerCmaes = R6Class("OptimizerCmaes",
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
-      ps = ParamSet$new(list(
-        ParamDbl$new("sigma", default = 0.5),
-        ParamFct$new("start_values", default = "random", levels = c("random", "center"))
-      ))
-      ps$values$start_values = "random"
+      param_set = ps(
+        sigma = p_dbl(default = 0.5),
+        start_values = p_fct(default = "random", levels = c("random", "center"))
+      )
+      param_set$values$start_values = "random"
       super$initialize(
-        param_set = ps,
+        param_set = param_set,
         param_classes = "ParamDbl",
         properties = "single-crit",
         packages = "adagio"
@@ -89,9 +90,10 @@ OptimizerCmaes = R6Class("OptimizerCmaes",
       pv$stopeval = .Machine$integer.max # make sure pureCMAES does not stop
       pv$stopfitness = -Inf
 
-      invoke(adagio::pureCMAES, fun = inst$objective_function,
-             lower = inst$search_space$lower, upper = inst$search_space$upper,
-             .args = pv)
+      if (length(pv$par) < 2) warning("CMA-ES is typically applied to search space dimensions between three and fifty. A lower search space dimension might crash.")
+
+      invoke(adagio::pureCMAES, fun = inst$objective_function, lower = inst$search_space$lower, 
+        upper = inst$search_space$upper, .args = pv)
     }
   )
 )
