@@ -53,7 +53,7 @@ Terminator = R6Class("Terminator",
     #' Set of control parameters for terminator.
     #' @param properties (`character()`)\cr
     #' Set of properties.
-    initialize = function(param_set = ParamSet$new(),
+    initialize = function(param_set = ps(),
       properties = character()) {
       self$param_set = assert_param_set(param_set)
       self$properties = assert_subset(properties,
