@@ -28,13 +28,10 @@ TerminatorClockTime = R6Class("TerminatorClockTime",
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
-      custom_check = function(x) {
-        check_class(x, "POSIXct")
-      }
-      ps = ParamSet$new(list(
-        ParamUty$new("stop_time", tags = "required", custom_check = custom_check)
-      ))
-      super$initialize(param_set = ps, properties = c("single-crit", "multi-crit"))
+      param_set = ps(
+        stop_time = p_uty(tags = "required", custom_check = function(x) check_class(x, "POSIXct"))
+      )
+      super$initialize(param_set = param_set, properties = c("single-crit", "multi-crit"))
       self$unit = "seconds"
     },
 
