@@ -6,6 +6,14 @@
 #' @description
 #' Class to terminate the optimization depending on the number of evaluations.
 #' An evaluation is defined by one resampling of a parameter value.
+#' The total number of evaluations \eqn{B} is defined as
+#'
+#' \deqn{
+#'    B = \mathrm{n_evals} + k * D
+#' }{
+#'    B = n_evals + k * D
+#' }
+#' where \eqn{D} is the dimension of the search space.
 #'
 #' @templateVar id evals
 #' @template section_dictionary_terminator
@@ -13,7 +21,9 @@
 #' @section Parameters:
 #' \describe{
 #' \item{`n_evals`}{`integer(1)`\cr
-#' Number of allowed evaluations, default is 100L.}
+#' See formula above. Default is 100.}
+#' \item{`k`}{`integer(1)`\cr
+#' See formula above. Default is 0.}
 #' }
 #'
 #' @family Terminator
@@ -21,7 +31,15 @@
 #' @export
 #' @examples
 #' TerminatorEvals$new()
+#'
+#' # 5 evaluations in total
 #' trm("evals", n_evals = 5)
+#'
+#' # 3 * [dimension of search space] evaluations in total
+#' trm("evals", n_evals = 0, k = 3)
+#'
+#' # (3 * [dimension of search space] + 1) evaluations in total
+#' trm("evals", n_evals = 1, k = 3)
 TerminatorEvals = R6Class("TerminatorEvals",
   inherit = Terminator,
   public = list(
@@ -29,10 +47,12 @@ TerminatorEvals = R6Class("TerminatorEvals",
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
-      ps = ParamSet$new(list(ParamInt$new("n_evals", lower = 1L, default = 100L,
-        tags = "required")))
-      ps$values = list(n_evals = 100L)
-      super$initialize(param_set = ps, properties = c("single-crit", "multi-crit"))
+      param_set = ps(
+        n_evals = p_int(lower = 0L, default = 100L, tags = "required"),
+        k = p_int(lower = 0L, default = 0L, tags = "required")
+      )
+      param_set$values = list(n_evals = 100L, k = 0L)
+      super$initialize(param_set = param_set, properties = c("single-crit", "multi-crit"))
       self$unit = "evaluations"
     },
 
@@ -42,13 +62,15 @@ TerminatorEvals = R6Class("TerminatorEvals",
     #' @return `logical(1)`.
     is_terminated = function(archive) {
       assert_r6(archive, "Archive")
-      archive$n_evals >= self$param_set$values$n_evals
+      pv = self$param_set$values
+      archive$n_evals >= pv$n_evals + pv$k * archive$search_space$length
     }
   ),
 
   private = list(
     .status = function(archive) {
-      max_steps = self$param_set$values$n_evals
+      pv = self$param_set$values
+      max_steps = pv$n_evals + pv$k * archive$search_space$length
       current_steps =  archive$n_evals
       c("max_steps" = max_steps, "current_steps" = current_steps)
     }
