@@ -51,6 +51,7 @@ test_that("Objective specialzations work", {
   FUN_1D_DT = function(xdt) data.table(y = xdt$x^2) # DT version oof FUN_1D in helper.R
   FUN_2D_DT = function(xdt) data.table(y = rowSums(xdt^2)) # same but FUN_2D
   FUN_2D_2D_DT = function(xdt) data.table(y1 = xdt[[1]]^2, y2 = -xdt[[2]]^2) # same as FUN_2D_2D
+  FUN_2D_DEPS_DT = function(xdt) data.table(y = rowSums(xdt^2, na.rm = TRUE))
 
   # Different function pairs, where the R function uses a different signature but they should do the same
   funs = list(
@@ -68,6 +69,10 @@ test_that("Objective specialzations work", {
     list( #2d x, 2d y
       rfun = ObjectiveRFun$new(fun = FUN_2D_2D, domain = PS_2D, codomain = FUN_2D_2D_CODOMAIN),
       rfun_dt = ObjectiveRFunDt$new(fun = FUN_2D_2D_DT, domain = PS_2D, codomain = FUN_2D_2D_CODOMAIN)
+    ),
+    list( #2d x with deps, 1d y
+      rfun = ObjectiveRFun$new(fun = FUN_2D_DEPS, domain = PS_2D_DEPS, check_values = FALSE), # dont check bc. we get NAs
+      rfun_dt = ObjectiveRFunDt$new(fun = FUN_2D_DEPS_DT, domain = PS_2D_DEPS, check_values = TRUE) # here NAs can get checked by assert_dt correctly
     )
   )
 
@@ -107,9 +112,9 @@ test_that("Objective specialzations work", {
     expect_equal(res3, fun2$eval_many(xdt1$transpose()))
 
     # multiple x values in one call
-    xdt3 = sampler$sample(3)
+    xdt3 = sampler$sample(10)
     res4 = fun1$eval_dt(xdt3$data)
-    expect_data_table(res4, nrows = 3, ncols = expected_ncols, any.missing = FALSE)
+    expect_data_table(res4, nrows = 10, ncols = expected_ncols, any.missing = FALSE)
     expect_equal(colnames(res4), expected_colnames)
     expect_equal(res4, fun2$eval_dt(xdt3$data))
 
@@ -120,48 +125,38 @@ test_that("Objective specialzations work", {
 })
 
 test_that("codomain assertions work", {
-  domain = ParamSet$new(list(ParamDbl$new("x", lower = -1, upper = 1)))
-  codomain = ParamSet$new(list(ParamDbl$new("y1", tags = "minimize")))
+  domain = ps(x = p_dbl(lower = -1, upper = 1))
+  codomain = ps(y1 = p_dbl(tags = "minimize"))
   expect_r6(Objective$new(domain = domain, codomain = codomain), "Objective")
 
-  domain = ParamSet$new(list(ParamDbl$new("x", lower = -1, upper = 1)))
-  codomain = ParamSet$new(list(ParamDbl$new("y1")))
+  codomain = ps(y1 = p_dbl())
   expect_error(Objective$new(domain = domain, codomain = codomain), "y1 in codomain contains no 'minimize' or 'maximize' tag")
 
-  domain = ParamSet$new(list(ParamDbl$new("x", lower = -1, upper = 1)))
-  codomain = ParamSet$new(list(ParamLgl$new("y1")))
+  codomain = ps(y1 = p_lgl())
   expect_error(Objective$new(domain = domain, codomain = codomain), "y1 in codomain is not numeric")
 
-  domain = ParamSet$new(list(ParamDbl$new("x", lower = -1, upper = 1)))
-  codomain = ParamSet$new(list(ParamDbl$new("y1", tags = c("minimize", "maximize"))))
+  codomain = ps(y1 = p_dbl(tags = c("minimize", "maximize")))
   expect_error(Objective$new(domain = domain, codomain = codomain), "y1 in codomain contains a 'minimize' and 'maximize' tag")
 
-  domain = ParamSet$new(list(ParamDbl$new("x", lower = -1, upper = 1)))
-  codomain = ParamSet$new(list(ParamDbl$new("y1", tags = "minimize"), ParamDbl$new("y2", tags = "maximize")))
+  codomain = ps(y1 = p_dbl(tags = "minimize"), y2 = p_dbl(tags = "maximize"))
   expect_r6(Objective$new(domain = domain, codomain = codomain), "Objective")
 
-  domain = ParamSet$new(list(ParamDbl$new("x", lower = -1, upper = 1)))
-  codomain = ParamSet$new(list(ParamDbl$new("y1"), ParamDbl$new("y2")))
+  codomain = ps(y1 = p_dbl(), y2 = p_dbl())
   expect_error(Objective$new(domain = domain, codomain = codomain), "y1 in codomain contains no 'minimize' or 'maximize' tag")
 
-  domain = ParamSet$new(list(ParamDbl$new("x", lower = -1, upper = 1)))
-  codomain = ParamSet$new(list(ParamDbl$new("y1", tags = "minimize"), ParamDbl$new("y2")))
+  codomain = ps(y1 = p_dbl(tags = "minimize"), y2 = p_dbl())
   expect_error(Objective$new(domain = domain, codomain = codomain), "y2 in codomain contains no 'minimize' or 'maximize' tag")
 
-  domain = ParamSet$new(list(ParamDbl$new("x", lower = -1, upper = 1)))
-  codomain = ParamSet$new(list(ParamDbl$new("y1", tags = "minimize"), ParamLgl$new("y2", tags = "maximize")))
+  codomain = ps(y1 = p_dbl(tags = "minimize"), y2 = p_lgl(tags = "maximize"))
   expect_error(Objective$new(domain = domain, codomain = codomain), "y2 in codomain is not numeric")
 
-  domain = ParamSet$new(list(ParamDbl$new("x", lower = -1, upper = 1)))
-  codomain = ParamSet$new(list(ParamLgl$new("y1", tags = "minimize"), ParamLgl$new("y2", tags = "maximize")))
+  codomain = ps(y1 = p_lgl(tags = "minimize"), y2 = p_lgl(tags = "maximize"))
   expect_error(Objective$new(domain = domain, codomain = codomain), "y1 in codomain is not numeric")
 
-  domain = ParamSet$new(list(ParamDbl$new("x", lower = -1, upper = 1)))
-  codomain = ParamSet$new(list(ParamDbl$new("y1", tags = "minimize"), ParamDbl$new("y2", tags = c("minimize", "maximize"))))
+  codomain = ps(y1 = p_dbl(tags = "minimize"), y2 = p_dbl(tags = c("minimize", "maximize")))
   expect_error(Objective$new(domain = domain, codomain = codomain), "y2 in codomain contains a 'minimize' and 'maximize' tag")
 
-  domain = ParamSet$new(list(ParamDbl$new("x", lower = -1, upper = 1)))
-  codomain = ParamSet$new(list(ParamDbl$new("y1", tags = c("minimize", "maximize")), ParamDbl$new("y2", tags = c("minimize", "maximize"))))
+  codomain = ps(y1 = p_dbl(tags = c("minimize", "maximize")), y2 = p_dbl(tags = c("minimize", "maximize")))
   expect_error(Objective$new(domain = domain, codomain = codomain), "y1 in codomain contains a 'minimize' and 'maximize' tag")
 })
 
@@ -180,7 +175,7 @@ test_that("check_values flag works", {
   obj = ObjectiveTestEval$new(domain = PS_2D, codomain = FUN_2D_CODOMAIN,
     check_values = TRUE)
   expect_error(obj$eval(list(x1 = 2, x2 = 1)),
-              fixed = "Assertion on 'X[[i]]' failed: x1: Element 1 is not <= 1.")
+              "<= 1.", fixed = TRUE)
 
   ObjectiveTestEvalMany = R6Class("ObjectiveTestEvalMany",
     inherit = Objective,
@@ -198,7 +193,7 @@ test_that("check_values flag works", {
   obj = ObjectiveTestEvalMany$new(domain = PS_2D, check_values = TRUE)
   xs = list(x1 = 2, x2 = 1)
   expect_error(obj$eval(list(x1 = 2, x2 = 1)),
-    fixed = "Assertion on 'X[[i]]' failed: x1: Element 1 is not <= 1.")
+    "<= 1.", fixed = TRUE)
 })
 
 test_that("check_values = TRUE with extra output works", {
@@ -228,14 +223,99 @@ test_that("check_values = TRUE with extra output works", {
 
 test_that("assertion on overlapping and reserved names works", {
   expect_error(Objective$new(domain = ps(x = p_lgl()), codomain = ps(x = p_dbl(tags = "maximize"))),
-    regexp = "Assertion on 'self$domain$ids()' failed: Must be disjunct from (x).",
+    regexp = "disjunct from (x).",
     fixed = TRUE)
 
   expect_error(Objective$new(domain = ps(batch_nr = p_lgl()), codomain = ps(x = p_dbl(tags = "maximize"))),
-    regexp = "Assertion on 'self$domain$ids()' failed: Must be disjunct from (x_domain,timestamp,batch_nr).",
+    regexp = "disjunct from (x_domain,timestamp,batch_nr).",
     fixed = TRUE)
 
   expect_error(Objective$new(domain = ps(x = p_lgl()), codomain = ps(timestamp = p_dbl(tags = "maximize"))),
-    regexp = "Assertion on 'self$codomain$ids()' failed: Must be disjunct from (x_domain,timestamp,batch_nr).",
+    regexp = "disjunct from (x_domain,timestamp,batch_nr).",
     fixed = TRUE)
 })
+
+test_that("ObjectiveRFunDt works with a list containing elements with different order", {
+  FUN = function(xdt) data.table(y = xdt$x)
+
+  rfun_dt = ObjectiveRFunDt$new(fun = FUN, domain = ps(x = p_int(), z = p_int()), codomain = ps(y = p_int(tags = "minimize")))
+
+  res = rfun_dt$eval_many(list(list(x = 1, z = 2), list(x = 1, z = 2)))
+  expect_equal(res, data.table(y = c(1, 1)))
+})
+
+test_that("ObjectiveRFunDt works with deps #141", {
+  FUN = function(xdt) {
+    pmap_dtr(xdt, function(x1, x2) {
+      data.table(y = if(is.na(x2)) x1 else x2)
+    })
+  }
+  domain = ps(x1 = p_int(), x2 = p_int())
+  domain$add_dep("x2", "x1", CondEqual$new(-1))
+  codomain = ps(y = p_dbl(tags = "minimize"))
+  rfun_dt = ObjectiveRFunDt$new(fun = FUN, domain = domain, codomain = codomain)
+
+  design = Design$new(
+    domain,
+    data.table(x1 = c(-1, 1), x2 = c(2, 2)),
+    remove_dupl = FALSE
+  )
+  xss = design$transpose(trafo = TRUE, filter_na = TRUE)
+  res = rfun_dt$eval_many(xss)
+  expect_equal(res, data.table(y = c(2, 1)))
+})
+
+test_that("Objective works with constants", {
+
+  # .eval implemented
+  ObjectiveTestEval = R6Class("ObjectiveTestEval",
+    inherit = Objective,
+    private = list(
+      .eval = function(xs, c) list(y = xs[["x"]]^2 + c)
+    )
+  )
+
+  objective = ObjectiveTestEval$new(domain = PS_1D, constants = ps(c = p_dbl()))
+  objective$constants$values$c = 1
+
+  expect_equal(objective$eval(list(x = 1)), list(y = 2))
+  expect_equal(objective$eval(list(x = 0)), list(y = 1))
+  expect_equal(objective$eval_many(list(list(x = 1), list(x = 0))), data.table(y = c(2, 1)))
+  expect_equal(objective$eval_dt(data.table(x = c(1, 0))), data.table(y = c(2, 1)))
+
+  # .eval_many implemented
+  ObjectiveTestEval = R6Class("ObjectiveTestEval",
+    inherit = Objective,
+    private = list(
+      .eval_many = function(xss, c) data.table(y = map_dbl(xss, function(xs) xs[["x"]]^2 + c))
+    )
+  )
+
+  objective = ObjectiveTestEval$new(domain = PS_1D, constants = ps(c = p_dbl()))
+  objective$constants$values$c = 1
+
+  expect_equal(objective$eval(list(x = 1)), list(y = 2))
+  expect_equal(objective$eval(list(x = 0)), list(y = 1))
+  expect_equal(objective$eval_many(list(list(x = 1), list(x = 0))), data.table(y = c(2, 1)))
+  expect_equal(objective$eval_dt(data.table(x = c(1, 0))), data.table(y = c(2, 1)))
+
+  # ObjectiveRFun
+  fun = function(xs, c) list(y = xs[["x"]]^2 + c)
+  objective = ObjectiveRFun$new(fun = fun, domain = PS_1D, constants = ps(c = p_dbl()))
+  objective$constants$values$c = 1
+
+  expect_equal(objective$eval(list(x = 1)), list(y = 2))
+  expect_equal(objective$eval(list(x = 0)), list(y = 1))
+  expect_equal(objective$eval_many(list(list(x = 1), list(x = 0))), data.table(y = c(2, 1)))
+  expect_equal(objective$eval_dt(data.table(x = c(1, 0))), data.table(y = c(2, 1)))
+
+  # ObjectiveRFunDt
+  fun = function(xdt, c) data.table(y = xdt[["x"]]^2 + c)
+  objective = ObjectiveRFunDt$new(fun = fun, domain = PS_1D, constants = ps(c = p_dbl()))
+  objective$constants$values$c = 1
+
+  expect_equal(objective$eval(list(x = 1)), list(y = 2))
+  expect_equal(objective$eval(list(x = 0)), list(y = 1))
+  expect_equal(objective$eval_many(list(list(x = 1), list(x = 0))), data.table(y = c(2, 1)))
+  expect_equal(objective$eval_dt(data.table(x = c(1, 0))), data.table(y = c(2, 1)))
+})
